
function [insi_avg,insi_std,NScount,NSrate,CV] = INSI(spiketimes,SimTimeInSeconds,StabilizationTime)
% Function by EA, adapted from Masquelier and Deco (2013)
% https://senselab.med.yale.edu/ModelDB/ShowModel?model=150437&file=/MasquelierDeco2013/#tabs-2

% This function takes in the spiketimes and the length of the simulation to
% calculate the "network spike" features: the average inter-network-spike
% interval, the standard dev of the INSI, the number of network spikes for
% the simulation, the network spikes per second, and the coefficient of
% variation for the network spikes.
    
    if nargin == 2
        StabilizationTime = 10;
    end


    thr = 50; % need at least 50 events to call it a network spike
    timeBin = 50e-3; % [s]
    
    spiketimes_post = spiketimes(spiketimes > StabilizationTime); % spikestimes that happen 
                                                   % after the settling period
                                                   % (manually set to 10s)
    if numel(spiketimes_post) <= 1 % if there aren't 2 spikes for whatever reason
        insi = 0; % there can't be any network spikes
        i_start = [];
    elseif (spiketimes_post(end)-spiketimes_post(1)) < timeBin % if the spikes are too close together
        insi = 0; % they don't count
        i_start = [];
    else
        % divide the spiketimes into 50e-3 s bins to see if reach threshold for network spike                                               
        h = histcounts(spiketimes_post,'BinEdges',...
            [spiketimes_post(1):timeBin:spiketimes_post(end)]);
        rate = h/60.0/timeBin; % h[0] is the counts and h[1] is the bin edges
        i_start = find((rate(2:end)>=thr).*(rate(1:end-1)<thr)>0); % these are 
                                                                   % indexes in the
                                                                   % histcounts
                                                                   % bins
        if numel(i_start) <= 1
            insi = NaN; % if there are no network spikes
        else
            insi = ( i_start(2:end) - i_start(1:end-1) )*timeBin; % convert to time intervals
        end
    end
    
    insi_avg = mean(insi);
    insi_std = std(insi);
    NScount = length(i_start);
    NSrate = NScount/SimTimeInSeconds;
    CV = insi_std/insi_avg;
end