
% Function by EA, developed based on Ana Rodriguez's 2016 Thesis from
% Bonnie Firestein's Lab at Rutgers (p 39 - 41)

% This function takes in the spiketimes and the length of the simulation to
% calculate the ISI, spike rate, and CV for every spike per neuron (electrode) 
 
function [isi_avg,isi_std,spikeRate_avg,spikeRate_std,CV] = ...
    ISI(spikeindexes,spiketimes,SimTimeInSeconds,StabilizationTime)
   
    nNeurons = length(unique(spikeindexes));
    isi = NaN(nNeurons,1);
    spikeRate = NaN(nNeurons,1);
                                                   
    for ii = 1:nNeurons
        neuronalSpikes = spiketimes(spikeindexes == ii-1); % get the spikes that correspond to current neuron (ii-1 to account for differential indexing in Python vs Matlab)
        neuronalSpikes = neuronalSpikes(neuronalSpikes > StabilizationTime);
        neuronalISI = neuronalSpikes(2:end) - neuronalSpikes(1:end-1); % get the ISIs for that neuron
        neuronalISI = neuronalISI(neuronalISI > 2e-3); % make sure those ISIs are > 2 ms apart
        isi(ii) = mean(neuronalISI);
        spikeRate(ii) = (length(neuronalISI)+1)/SimTimeInSeconds; % + 1 to convert from ISIs to nSpikes --> [spikes/s]
    end
    
    isi_avg = nanmean(isi);
    isi_std = nanstd(isi);
    spikeRate_avg = mean(spikeRate);
    spikeRate_std = std(spikeRate);
    CV = isi_std/isi_avg;
end

